@@ -2,7 +2,6 @@
  *
  * The des block cipher.
  *
- * $Id: des.c,v 1.6 2002/01/14 16:02:38 nisse Exp $
  */
 
 /* nettle, low-level cryptographics library
@@ -30,14 +29,15 @@
  *	Please see the file `descore.README' for the complete copyright notice.
  */
 
-#include "des.h"
-
-#include "desCode.h"
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
 
 #include <assert.h>
 
-static ENCRYPT(DesSmallFipsEncrypt,TEMPSMALL, LOADFIPS,KEYMAPSMALL,SAVEFIPS)
-static DECRYPT(DesSmallFipsDecrypt,TEMPSMALL, LOADFIPS,KEYMAPSMALL,SAVEFIPS)
+#include "des.h"
+
+#include "desCode.h"
 
 /* various tables */
 
@@ -56,6 +56,9 @@ parity[] = {
 #include	"parity.h"
 };
 
+static ENCRYPT(DesSmallFipsEncrypt,TEMPSMALL, LOADFIPS,KEYMAPSMALL,SAVEFIPS)
+static DECRYPT(DesSmallFipsDecrypt,TEMPSMALL, LOADFIPS,KEYMAPSMALL,SAVEFIPS)
+
 void
 des_fix_parity(unsigned length, uint8_t *dst,
 	       const uint8_t *src)
@@ -224,7 +227,7 @@ des_set_key(struct des_ctx *ctx, const uint8_t *key)
 }
 
 void
-des_encrypt(struct des_ctx *ctx,
+des_encrypt(const struct des_ctx *ctx,
 	    unsigned length, uint8_t *dst,
 	    const uint8_t *src)
 {
@@ -241,7 +244,7 @@ des_encrypt(struct des_ctx *ctx,
 }
 
 void
-des_decrypt(struct des_ctx *ctx,
+des_decrypt(const struct des_ctx *ctx,
 	    unsigned length, uint8_t *dst,
 	    const uint8_t *src)
 {
