@@ -23,13 +23,18 @@
  * MA 02111-1307, USA.
  */
 
-#include "sexp.h"
-
-#include "macros.h"
+#if HAVE_CONFIG_H
+# include "config.h"
+#endif
 
 #include <stdlib.h>
 #include <string.h>
 
+#include "sexp.h"
+
+#include "macros.h"
+#include "nettle-internal.h"
+
 /* Initializes the iterator, but one has to call next to get to the
  * first element. */
 static void
@@ -298,7 +303,7 @@ sexp_iterator_check_type(struct sexp_iterator *iterator,
 const uint8_t *
 sexp_iterator_check_types(struct sexp_iterator *iterator,
 			  unsigned ntypes,
-			  const uint8_t **types)
+			  const uint8_t * const *types)
 {
   if (sexp_iterator_enter_list(iterator)
       && iterator->type == SEXP_ATOM
@@ -317,14 +322,14 @@ sexp_iterator_check_types(struct sexp_iterator *iterator,
 int
 sexp_iterator_assoc(struct sexp_iterator *iterator,
 		    unsigned nkeys,
-		    const uint8_t **keys,
+		    const uint8_t * const *keys,
 		    struct sexp_iterator *values)
 {
-  int *found;
+  TMP_DECL(found, int, NETTLE_MAX_SEXP_ASSOC);
   unsigned nfound;
   unsigned i;
-  
-  found = alloca(nkeys * sizeof(*found));
+
+  TMP_ALLOC(found, nkeys);
   for (i = 0; i<nkeys; i++)
     found[i] = 0;
 
