@@ -147,7 +147,7 @@ main(int argc, char **argv)
 {
   if (argc > 1)
     {
-      if (argc == 2 && strcmp(argv[1], "-v"))
+      if (argc == 2 && !strcmp(argv[1], "-v"))
 	verbose = 1;
       else
 	{
@@ -341,6 +341,34 @@ test_hash(const struct nettle_hash *hash,
   free(buffer);
 }
 
+void
+test_hash_large(const struct nettle_hash *hash,
+		unsigned count, unsigned length,
+		uint8_t c,
+		const uint8_t *digest)
+{
+  void *ctx = xalloc(hash->context_size);
+  uint8_t *buffer = xalloc(hash->digest_size);
+  uint8_t *data = xalloc(length);
+  unsigned i;
+
+  memset(data, c, length);
+
+  hash->init(ctx);
+  for (i = 0; i < count; i++)
+    hash->update(ctx, length, data);
+  hash->digest(ctx, hash->digest_size, buffer);
+
+  print_hex(hash->digest_size, buffer);
+
+  if (!MEMEQ(hash->digest_size, digest, buffer))
+    FAIL();
+
+  free(ctx);
+  free(buffer);
+  free(data);
+}
+
 void
 test_armor(const struct nettle_armor *armor,
            unsigned data_length,
@@ -596,6 +624,49 @@ test_rsa_sha1(struct rsa_public_key *pub,
   mpz_clear(signature);
 }
 
+void
+test_rsa_sha256(struct rsa_public_key *pub,
+	     struct rsa_private_key *key,
+	     mpz_t expected)
+{
+  struct sha256_ctx sha256;
+  mpz_t signature;
+
+  sha256_init(&sha256);
+  mpz_init(signature);
+
+  SIGN(key, sha256, "The magic words are squeamish ossifrage", signature);
+
+  if (verbose)
+    {
+      fprintf(stderr, "rsa-sha256 signature: ");
+      mpz_out_str(stderr, 16, signature);
+      fprintf(stderr, "\n");
+    }
+
+  if (mpz_cmp(signature, expected))
+    FAIL();
+  
+  /* Try bad data */
+  if (VERIFY(pub, sha256,
+	     "The magick words are squeamish ossifrage", signature))
+    FAIL();
+
+  /* Try correct data */
+  if (!VERIFY(pub, sha256,
+	      "The magic words are squeamish ossifrage", signature))
+    FAIL();
+
+  /* Try bad signature */
+  mpz_togglebit(signature, 17);
+
+  if (VERIFY(pub, sha256,
+	     "The magic words are squeamish ossifrage", signature))
+    FAIL();
+
+  mpz_clear(signature);
+}
+
 #undef SIGN
 #undef VERIFY
 
