@@ -29,6 +29,21 @@
 #include "aes.h"
 #include "sha.h"
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
+/* Name mangling */
+#define yarrow256_init nettle_yarrow256_init
+#define yarrow256_seed nettle_yarrow256_seed
+#define yarrow256_update nettle_yarrow256_update
+#define yarrow256_random nettle_yarrow256_random
+#define yarrow256_is_seeded nettle_yarrow256_is_seeded
+#define yarrow256_needed_sources nettle_yarrow256_needed_sources
+#define yarrow256_force_reseed nettle_yarrow256_force_reseed
+#define yarrow_key_event_init nettle_yarrow_key_event_init
+#define yarrow_key_event_estimate nettle_yarrow_key_event_estimate
+
 enum yarrow_pool_id { YARROW_FAST = 0, YARROW_SLOW = 1 };
 
 struct yarrow_source
@@ -70,7 +85,7 @@ yarrow256_init(struct yarrow256_ctx *ctx,
 void
 yarrow256_seed(struct yarrow256_ctx *ctx,
 	       unsigned length,
-	       uint8_t *seed_file);
+	       const uint8_t *seed_file);
 
 /* Returns 1 on reseed */
 int
@@ -109,4 +124,8 @@ unsigned
 yarrow_key_event_estimate(struct yarrow_key_event_ctx *ctx,
 			  unsigned key, unsigned time);
   
+#ifdef __cplusplus
+}
+#endif
+
 #endif /* NETTLE_YARROW_COMPAT_H_INCLUDED */
